# Changelog
:Info: This is the changelog for kb.
:Author: gnc <nebbionegiuseppe@gmail.com>
:Copyright: © 2020, gnc.
:License: GPLv3 (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2020-10-16
:Version: 0.1.1

## Version History

0.1.1 
    * Initial release.
0.1.2
    * Fixed important bugs of 0.1.1
    * Refactored
    * Added cross-platform binaries
    * Included docker image
    * Ready for pypi publishing
0.1.3
    * Added support for brew (with brew tap)
    * Fixed minor bugs
    * Fixed update mode '-e' flag
    * Fixed Windows bugs
    * Fixed cross-platforms tests
    * Improved continuous integration
Draft 0.1.4
    * Added body "-b" function in add
    * Fixed bugs related to the update function
    * Added templates
    * Added schema migration logic
    * Updated docs with a TOC

